@@ -22,7 +22,9 @@ from yt.data_objects.grid_patch import \
     AMRGridPatch
 from yt.data_objects.static_output import \
     Dataset, ParticleFile
-from yt.funcs import mylog
+from yt.funcs import \
+    mylog, \
+    setdefaultattr
 from yt.geometry.grid_geometry_handler import \
     GridIndex
 from yt.geometry.particle_geometry_handler import \
@@ -78,7 +80,11 @@ class FLASHHierarchy(GridIndex):
             self.num_grids = self.dataset._find_parameter(
                 "integer", "globalnumblocks", True)
         except KeyError:
-            self.num_grids = self._handle["/simulation parameters"][0][0]
+            try:
+                self.num_grids = \
+                    self._handle['simulation parameters']['total blocks'][0]
+            except KeyError:
+                self.num_grids = self._handle["/simulation parameters"][0][0]
         
     def _parse_index(self):
         f = self._handle # shortcut
@@ -212,7 +218,9 @@ class FLASHDataset(Dataset):
             part_time = self._particle_handle.handle.get('real scalars')[0][1]
             plot_time = self._handle.handle.get('real scalars')[0][1]
             if not np.isclose(part_time, plot_time):
-                raise IOError('%s and  %s are not at the same time.' % (self.particle_filename, filename))
+                self._particle_handle = self._handle
+                mylog.warning('%s and %s are not at the same time. ' % (self.particle_filename, filename) +
+                              'This particle file will not be used.')
 
         # These should be explicitly obtained from the file, but for now that
         # will wait until a reorganization of the source tree and better
@@ -246,13 +254,14 @@ class FLASHDataset(Dataset):
         else:
             length_factor = 1.0
             temperature_factor = 1.0
-        self.magnetic_unit = self.quan(b_factor, "gauss")
 
-        self.length_unit = self.quan(length_factor, "cm")
-        self.mass_unit = self.quan(1.0, "g")
-        self.time_unit = self.quan(1.0, "s")
-        self.velocity_unit = self.quan(1.0, "cm/s")
-        self.temperature_unit = self.quan(temperature_factor, "K")
+        setdefaultattr(self, 'magnetic_unit', self.quan(b_factor, "gauss"))
+        setdefaultattr(self, 'length_unit', self.quan(length_factor, "cm"))
+        setdefaultattr(self, 'mass_unit', self.quan(1.0, "g"))
+        setdefaultattr(self, 'time_unit', self.quan(1.0, "s"))
+        setdefaultattr(self, 'velocity_unit', self.quan(1.0, "cm/s"))
+        setdefaultattr(
+            self, 'temperature_unit', self.quan(temperature_factor, "K"))
 
     def set_code_units(self):
         super(FLASHDataset, self).set_code_units()
@@ -312,11 +321,14 @@ class FLASHDataset(Dataset):
                 if hn not in self._handle:
                     continue
                 if hn is 'simulation parameters':
-                    zipover = zip(self._handle[hn].dtype.names,self._handle[hn][0])
+                    zipover = ((name, self._handle[hn][name][0])
+                               for name in self._handle[hn].dtype.names)
                 else:
                     zipover = zip(self._handle[hn][:,'name'],self._handle[hn][:,'value'])
                 for varname, val in zipover:
                     vn = varname.strip()
+                    if hasattr(vn, 'decode'):
+                        vn = vn.decode("ascii", "ignore")
                     if hn.startswith("string"):
                         pval = val.strip()
                     else:
@@ -326,7 +338,7 @@ class FLASHDataset(Dataset):
                                    "scalar of the same name".format(hn[:-1],vn))
                     if hasattr(pval, 'decode'):
                         pval = pval.decode("ascii", "ignore")
-                    self.parameters[vn.decode("ascii", "ignore")] = pval
+                    self.parameters[vn] = pval
         
         # Determine block size
         try:
